@@ -44,14 +44,9 @@ struct _ETzMap
 	GstTool *tool; /* This is not the way to do it, will fix later */
 };
 
-
-/* Dirty time-admin hook */
-extern ETzMap *tzmap;
-
-
 /* --- Fake widget --- */
 
-ETzMap     *e_tz_map_new                  (GstTimeTool *tool);
+ETzMap     *e_tz_map_new                  (GstTool *tool);
 TzDB       *e_tz_map_get_tz_db            (ETzMap *tzmap);
 void        e_tz_map_set_tz_from_name     (ETzMap *tzmap, gchar *name);
 gchar      *e_tz_map_get_selected_tz_name (ETzMap *tzmap);
